from rosetta import *
init()

#set up ligand parameters
params_list = Vector1(['ATP.params'])
res_set = generate_nonstandard_residue_set(params_list) 

#read in PDB file with ligand
p = Pose()
pose_from_pdb(p, res_set, "PKA.pdb")

starting_p = Pose()
starting_p.assign(p)
dock_jump = 1

#set up scoring function
scorefxn = create_score_function("ligand")

#set up initial perturbation movers
dock_pert = RigidBodyPerturbMover(dock_jump, 3, 8) #3A translation, 8 degrees rotation
spin = RigidBodySpinMover( dock_jump )
slide_into_contact = FaDockingSlideTogether( dock_jump )

#set up DockingHighRes mover
docking_prot = DockingProtocol()
docking_highres = DockingHighRes(scorefxn, dock_jump)

movemap = MoveMap()
movemap.set_chi(337, True) #allow ligand torsion angles to minimize during docking
movemap.set_jump(1, True)  #allow ligand rigid body position to minimize during docking
docking_highres.set_move_map(movemap)

print "set up job distributor"
jd = PyJobDistributor("lig_dock_output", 50, scorefxn)

print "beginning docking..."

while (jd.job_complete == False):
	p.assign(starting_p)

	print "initial perturbation"
	dock_pert.apply(p)
	spin.apply(p)
	slide_into_contact.apply(p)

	print "high resolution stage docking"
	docking_highres.apply(p)

	print "outputting decoy..."
	jd.output_decoy(p)

print "docking complete!"

